@@ -1,7 +1,7 @@
 use ron::from_str;
 use std::collections::HashMap;
 
-const DEFAULT_MAPPING: &str = include_str!("../../data/code_page_437.mapping");
+const DEFAULT_MAPPING: &str = include_str!("../../assets/code_page_437.mapping");
 
 pub struct GlyphMapping {
     mapping: HashMap<char, (usize, usize)>,
@@ -9,6 +9,12 @@ pub struct GlyphMapping {
     //size: (usize, usize),
 }
 
+impl Default for GlyphMapping {
+    fn default() -> Self {
+        GlyphMapping::code_page_437()
+    }
+}
+
 impl GlyphMapping {
     pub fn new(mapping: HashMap<char, usize>, width: usize) -> Self {
         let mut indexed = HashMap::new();
@@ -47,12 +53,6 @@ impl GlyphMapping {
     }
 }
 
-impl Default for GlyphMapping {
-    fn default() -> Self {
-        GlyphMapping::code_page_437()
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
